Char8

Struct Char8 

pub struct Char8(/* private fields */);
An 8-bit unicode scalar value, limited to basic latin and latin-1 subsets.

This is the only scalar type without memory layout optimization because each possible value is a valid unicode scalar. Therefore Option<Char8> is the same size as Char16 or Option<Char16> (2 bytes).

See also: Char7, Char16, Char24, Char32, char.

Implementations

Source

impl Char8

pub const fn byte_len(self) -> usize

Returns the number of bytes needed to represent the scalar value.

pub const fn len_utf8(self) -> usize

Returns the number of bytes needed to encode in UTF-8.

pub const fn len_utf16(self) -> usize

Returns the number of bytes needed to encode in UTF-16.

pub const fn to_digit(self, radix: u32) -> Option<u32>

Converts the scalar to a digit in the given radix.

‘Digit’ is defined to be only the following characters: 0-9, a-z, A-Z.

Errors

Returns None if the char does not refer to a digit in the given radix.

Panics

Panics if given a radix larger than 36.

pub const fn is_nul(self) -> bool

Returns true if this is the nul character (0x00).

pub const fn is_digit(self, radix: u32) -> bool

Checks if the unicode scalar is a digit in the given radix.

See also to_digit.

Source

impl Char8

pub const MAX: Char8

The highest unicode scalar a Char8 can represent, '\u{FF}'.

pub const fn from_char7(c: Char7) -> Char8

Converts a Char7 to Char8.

pub const fn try_from_char16(c: Char16) -> Result<Char8>

Tries to convert a Char16 to Char8.

pub const fn try_from_char24(c: Char24) -> Result<Char8>

Tries to convert a Char24 to Char8.

pub const fn try_from_char32(c: Char32) -> Result<Char8>

Tries to convert a Char32 to Char8.

pub const fn try_from_char(c: char) -> Result<Char8>

Tries to convert a char to Char8.

pub const fn try_to_char7(self) -> Result<Char7>

Tries to convert this Char8 to Char7.

pub const fn to_char16(self) -> Char16

Converts this Char8 to Char16.

pub const fn to_char24(self) -> Char24

Converts this Char8 to Char24.

pub const fn to_char32(self) -> Char32

Converts this Char8 to Char32.

pub const fn to_char(self) -> char

Converts this Char8 to char.

pub const fn to_u32(self) -> u32

Converts this Char8 to u32.

pub const fn to_utf8_bytes(self) -> [u8; 2]

Converts this Char8 to an UTF-8 encoded sequence of bytes.

Note that this function always returns a 2-byte array, but the actual UTF-8 sequence may be shorter. The unused bytes are set to 0.

pub const fn is_noncharacter(self) -> bool

Returns true if this unicode scalar is a noncharacter.

pub const fn is_character(self) -> bool

Returns true if this unicode scalar is an abstract character.

pub const fn is_ascii(self) -> bool

Checks if the value is within the ASCII range.

pub const fn to_ascii_uppercase(self) -> Char8

Makes a copy of the value in its ASCII upper case equivalent.

ASCII letters ‘a’ to ‘z’ are mapped to ‘A’ to ‘Z’, but non-ASCII letters are unchanged.

pub const fn to_ascii_lowercase(self) -> Char8

Makes a copy of the value in its ASCII lower case equivalent.

ASCII letters ‘A’ to ‘Z’ are mapped to ‘a’ to ‘z’, but non-ASCII letters are unchanged.