pub type NonNulEgc8 = StaticNonNulEgc<1>;Expand description
An 8-bit EGC, with fixed capacity of 1 byte, no nul chars.
Aliased Type
pub struct NonNulEgc8(/* private fields */);Trait Implementations
Sourceimpl From<Char7> for NonNulEgc8
impl From<Char7> for NonNulEgc8
Sourcefn from(c: Char7) -> NonNulEgc8
fn from(c: Char7) -> NonNulEgc8
Converts to this type from the input type.
Sourceimpl TryFrom<Char8> for NonNulEgc8
impl TryFrom<Char8> for NonNulEgc8
Sourcetype Error = TextosError
type Error = TextosError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<Char16> for NonNulEgc8
impl TryFrom<Char16> for NonNulEgc8
Sourcetype Error = TextosError
type Error = TextosError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<Char24> for NonNulEgc8
impl TryFrom<Char24> for NonNulEgc8
Sourcetype Error = TextosError
type Error = TextosError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<Char32> for NonNulEgc8
impl TryFrom<Char32> for NonNulEgc8
Sourcetype Error = TextosError
type Error = TextosError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<char> for NonNulEgc8
impl TryFrom<char> for NonNulEgc8
Sourcetype Error = TextosError
type Error = TextosError
The type returned in the event of a conversion error.